/*****************************************************************************
 * XMClib v2.2.0 - XMC Peripheral Driver Library
 *
 * Copyright (c) 2015-2020, Infineon Technologies AG
 * All rights reserved.
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer,
 * must be included in all copies of the Software, in whole or in part, and
 * all derivative works of the Software, unless such copies or derivative
 * works are solely in the form of machine-executable object code generated by
 * a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 * To improve the quality of the software, users are encouraged to share
 * modifications, enhancements or bug fixes with Infineon Technologies AG
 * at XMCSupport@infineon.com.
 *****************************************************************************
 * @file
 * @date 29 Jan, 2021
 * @version 1.0.0
 *
 * @brief XMC4200 Application kit CCU8 slices sync start
 *
 * History <br>
 *
 * Version 1.0.0 Initial <br>
 *
 */

#include "xmc_scu.h"
#include "xmc_gpio.h"
#include "xmc_ccu8.h"

static const XMC_CCU8_SLICE_COMPARE_CONFIG_t ccu8_config =
{
  .timer_mode = XMC_CCU8_SLICE_TIMER_COUNT_MODE_EA,
  .prescaler_initval = 0
};

static const XMC_CCU8_SLICE_EVENT_CONFIG_t start_event_config =
{
  .mapped_input = CCU80_IN0_SCU_GSC80,
  .edge = XMC_CCU8_SLICE_EVENT_EDGE_SENSITIVITY_RISING_EDGE
};

int main(void)
{
  XMC_CCU8_SetModuleClock(CCU80, XMC_CCU8_CLOCK_SCU);
  XMC_CCU8_Init(CCU80, XMC_CCU8_SLICE_MCMS_ACTION_TRANSFER_PR_CR);

  XMC_CCU8_EnableClock(CCU80, 0);
  XMC_CCU8_SLICE_CompareInit(CCU80_CC80, &ccu8_config);
  XMC_CCU8_SLICE_SetTimerPeriodMatch(CCU80_CC80, 0xf);
  XMC_CCU8_SLICE_SetTimerCompareMatch(CCU80_CC80, XMC_CCU8_SLICE_COMPARE_CHANNEL_1, 0x7);

  XMC_CCU8_EnableClock(CCU80, 1);
  XMC_CCU8_SLICE_CompareInit(CCU80_CC81, &ccu8_config);
  XMC_CCU8_SLICE_SetTimerPeriodMatch(CCU80_CC81, 0xf);
  XMC_CCU8_SLICE_SetTimerCompareMatch(CCU80_CC81, XMC_CCU8_SLICE_COMPARE_CHANNEL_1, 0x7);

  XMC_CCU8_EnableShadowTransfer(CCU80, XMC_CCU8_SHADOW_TRANSFER_SLICE_0 | XMC_CCU8_SHADOW_TRANSFER_SLICE_1);

  XMC_CCU8_SLICE_ConfigureEvent(CCU80_CC80, XMC_CCU8_SLICE_EVENT_0, &start_event_config);
  XMC_CCU8_SLICE_StartConfig(CCU80_CC80, XMC_CCU8_SLICE_EVENT_0, XMC_CCU8_SLICE_START_MODE_TIMER_START_CLEAR);

  XMC_CCU8_SLICE_ConfigureEvent(CCU80_CC81, XMC_CCU8_SLICE_EVENT_0, &start_event_config);
  XMC_CCU8_SLICE_StartConfig(CCU80_CC81, XMC_CCU8_SLICE_EVENT_0, XMC_CCU8_SLICE_START_MODE_TIMER_START_CLEAR);

  XMC_GPIO_SetOutputStrength(P0_5, XMC_GPIO_OUTPUT_STRENGTH_STRONG_SOFT_EDGE);
  XMC_GPIO_SetMode(P0_5, XMC_GPIO_MODE_OUTPUT_PUSH_PULL | P0_5_AF_CCU80_OUT00);
  XMC_GPIO_SetOutputStrength(P0_4, XMC_GPIO_OUTPUT_STRENGTH_STRONG_SOFT_EDGE);
  XMC_GPIO_SetMode(P0_4, XMC_GPIO_MODE_OUTPUT_PUSH_PULL | P0_4_AF_CCU80_OUT10);

  XMC_SCU_SetCcuTriggerHigh(SCU_GENERAL_CCUCON_GSC80_Msk);

  while(1U);
}
